@@ -27,6 +27,12 @@ import cellconstructor as CC
 import scipy, scipy.linalg
 import numpy as np
 import os
+import json
+class NumpyEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, np.ndarray):
+            return obj.tolist()
+        return json.JSONEncoder.default(self, obj)
 
 
 # Here some usefull functions to solve linear systems
